@@ -16,6 +16,8 @@
 #' @param B a matrix, generally the \code{.B} slot in a
 #' \code{\linkS4class{sandwich_components}} object created in
 #' \code{\link{estimate_sandwich_matrices}}
+#' @param solver the function used to compute the inverse of \code{A}, Defaults
+#' to \code{\link{solve}}
 #'
 #' @return the \code{matrix} \code{Ainv \%*\% B \%*\% t(Ainv)}
 #' @export
@@ -24,9 +26,8 @@
 #' B <- matrix(4, nrow = 2, ncol = 2)
 #' compute_sigma(A = A, B = B)
 #------------------------------------------------------------------------------#
-
-compute_sigma <- function(A, B){
-  Ainv <- solve(A)
+compute_sigma <- function(A, B, solver = solve){
+  Ainv <- solver(A)
   Ainv %*% B %*% t(Ainv)
 }
 
@@ -35,7 +36,7 @@ compute_sigma <- function(A, B){
 #'
 #' @param .l a list of matrices
 #' @param .w a numeric vector of weights
-#' @export
+#' @keywords internal
 #------------------------------------------------------------------------------#
 
 compute_sum_of_list <- function(.l, .w = numeric(0)){
@@ -60,7 +61,7 @@ compute_sum_of_list <- function(.l, .w = numeric(0)){
 #' Either \code{.w} or \code{.wFUN} must be specified but not both.
 #'
 #' @importFrom methods formalArgs
-#' @export
+#' @keywords internal
 #------------------------------------------------------------------------------#
 
 compute_pairwise_sum_of_list <- function(.l, .w = NULL, .wFUN = NULL, ...){
